import React from "react";

const Star = ({
    size = 5,
    fill = "#00000000",
    stroke = "#DAA520",
    favouriteList,
    setFavouriteList,
    movie,
}) => {
    // Calculate points for a five-pointed star
    const points = [];
    const outerRadius = size / 2;
    const innerRadius = outerRadius * 0.382; // Golden ratio

    for (let i = 0; i < 10; i++) {
        const radius = i % 2 === 0 ? outerRadius : innerRadius;
        const angle = (Math.PI / 5) * i - Math.PI / 2;
        const x = radius * Math.cos(angle) + size / 2;
        const y = radius * Math.sin(angle) + size / 2;
        points.push(`${x},${y}`);
    }

    const handleFavouriteList = () => {
        favouriteList?.includes(movie?.imdbID)
            ? setFavouriteList((prevList) =>
                  prevList?.filter((id) => id !== movie?.imdbID)
              )
            : setFavouriteList((prevList) => [...prevList, movie?.imdbID]);
        let localStorageData = JSON.parse(window.localStorage.getItem("favouriteMovies"));
        console.log(localStorageData)
        window.localStorage.setItem("favouriteMovies", JSON.stringify({movies: [...localStorageData, movie]}));
    };

    return (
        <svg
            height="1em"
            width="1em"
            viewBox={`0 0 ${size} ${size}`}
            className="absolute top-1 right-1"
            onClick={handleFavouriteList}
        >
            <polygon
                height="1em"
                width="1em"
                points={points.join(" ")}
                fill={fill}
                stroke={stroke}
                strokeWidth={size / 15}
                className="drop-shadow-2xl shadow-[#000] shadow-2xl"
            />
        </svg>
    );
};

export default Star;
